# ProjectCategoryMatcherRemoveDto


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**matcher_id** | **int** |  | 

## Example

```python
from src.client.generated.models.project_category_matcher_remove_dto import ProjectCategoryMatcherRemoveDto

# TODO update the JSON string below
json = "{}"
# create an instance of ProjectCategoryMatcherRemoveDto from a JSON string
project_category_matcher_remove_dto_instance = ProjectCategoryMatcherRemoveDto.from_json(json)
# print the JSON string representation of the object
print(ProjectCategoryMatcherRemoveDto.to_json())

# convert the object into a dict
project_category_matcher_remove_dto_dict = project_category_matcher_remove_dto_instance.to_dict()
# create an instance of ProjectCategoryMatcherRemoveDto from a dict
project_category_matcher_remove_dto_from_dict = ProjectCategoryMatcherRemoveDto.from_dict(project_category_matcher_remove_dto_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


